The freq_tools Module — pysimsearch v0.30 documentation

### Navigation

- index
- modules |
- next |
- previous |
- pysimsearch v0.30 documentation »

# The `freq_tools` Module

Sample usage as a script:

    $ python freq_tools --list doc_list -o output.df
    Processing...

`pysimsearch.freq_tools.` `compute_df`(files)

  Computes document frequency counts by processing a collection of files Returns a dictionary of the form {term: doc_freq}

`pysimsearch.freq_tools.` `main`()

  Commandline interface for generating document frequency indexes

`pysimsearch.freq_tools.` `read_df`(df_file)

  Reads a document frequency file for use in applying df term weighting Returns a dictionary of the form {term: doc_freq}

`pysimsearch.freq_tools.` `write_df`(df_dict, df_file)

  Writes the document frequency data structure to file df_dict is a dictionary of the form {term: doc_freq}

  TODO: sort order?

### Navigation

- index
- modules |
- next |
- previous |
- pysimsearch v0.30 documentation »